;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "clojure-mode-extra-font-locking" "20250527.840"
  "Extra font-locking for Clojure mode."
  '((clojure-mode "3.0"))
  :url "https://github.com/clojure-emacs/clojure-mode"
  :commit "d336db623e7ae8cffff50aaaea3f1b05cc4ccecb"
  :revdesc "d336db623e7a"
  :keywords '("languages" "lisp")
  :authors '(("Bozhidar Batsov" . "bozhidar@batsov.dev"))
  :maintainers '(("Bozhidar Batsov" . "bozhidar@batsov.dev")))
